==> ejc-bpmdesktop-impl-3.0.0-20230206.012654-16-sources.jar: com/ejianc/business/desktop/controller/WarnController.java <==
package com.ejianc.business.desktop.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.center.api.IWarnCenterApi;
import com.ejianc.business.center.vo.EarlyWarnTransVO;
import com.ejianc.business.desktop.service.IWarnService;
import com.ejianc.business.desktop.vo.TaskVO;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.message.vo.PushMsgParameter;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author:sunxy
 * @Description:超期待办预警
 * @date 2022/6/6 11:22
 */
@RestController
@RequestMapping(value = "/warn/")
public class WarnController {
//       * * * 26 * ?            {"dispatchCode":"WARNING000110"}
   //    dispatchWarningHandler
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IWarnService warnService;
    @Autowired
    private IWarnCenterApi warnCenterApi;

    @Autowired
    private IOrgApi iOrgApi;

    static  String  PC_URL = "/ejc-task-frontend/#/personWarnCenter";

    @Autowired
    private IPushMessageApi pushMessageApi;
    //不能同时发送企业微信和系统消息
    public boolean sendSys(String receiverId,Integer sum){

        PushMsgParameter parameter = new PushMsgParameter();
        List<String> channel = new ArrayList<>();
       // channel.add(PushMsgParameter.CHANNEL_TYPE_WEIXIN);//发送企业微信标志
        channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
        String[] receivers = {receiverId};
        parameter.setReceivers(receivers);// 收信人
        parameter.setChannel(channel.toArray(new String[channel.size()]));// 消息类型
        parameter.setMsgType("earlywarning");//预警消息
        parameter.setSubject("您共有"+sum+"个预警超期未处理！");// 标题
        parameter.setContent("内容");// 内容
        parameter.setPcUrl(PC_URL);// pc端url
        parameter.setMobileUrl(PC_URL);// 移动端url
        parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
        parameter.setSendUserId(InvocationInfoProxy.getUserid());
        JSONObject weixineeParams = new JSONObject();
        weixineeParams.put("agentid", "1000038");//企业微信应用id
        weixineeParams.put("secret", "0n0MCtZ1vNtJsKQWPIREQ1UNMM8BXDkQZat6nbRqGGE");//企业微信secret
        weixineeParams.put("msgtype", "textcard");
        weixineeParams.put("title", "预警消息通知");
        weixineeParams.put("description", "您共有"+sum+"个预警超期未处理！");
        weixineeParams.put("url", ("/csqlh.zzyjjt.com"+PC_URL));//移动端点击的url
        weixineeParams.put("btntxt", "点击查看");
        parameter.setWeixineeParams(weixineeParams);

        CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
        if (result.isSuccess()) {
            logger.error("消息发送成功---------------->,接收人:{}," + result.getMsg(), Arrays.toString(receivers));

            return true;
        } else {
            logger.error("消息发送失败---------------->" + result.getMsg());
            return false;
        }
    }
    public boolean sendWeixin(String receiverId,Integer sum){

        PushMsgParameter parameter = new PushMsgParameter();
        List<String> channel = new ArrayList<>();
        channel.add(PushMsgParameter.CHANNEL_TYPE_WEIXIN);//发送企业微信标志
        //channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
        String[] receivers = {receiverId};
        parameter.setReceivers(receivers);// 收信人
        parameter.setChannel(channel.toArray(new String[channel.size()]));// 消息类型
        parameter.setMsgType("earlywarning");//预警消息
        parameter.setSubject("您共有"+sum+"个预警超期未处理！");// 标题
        parameter.setContent("内容");// 内容
        parameter.setPcUrl(PC_URL);// pc端url
        parameter.setMobileUrl(PC_URL);// 移动端url
        parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
        parameter.setSendUserId(InvocationInfoProxy.getUserid());
        JSONObject weixineeParams = new JSONObject();
        weixineeParams.put("agentid", "1000038");//企业微信应用id
        weixineeParams.put("secret", "0n0MCtZ1vNtJsKQWPIREQ1UNMM8BXDkQZat6nbRqGGE");//企业微信secret
        weixineeParams.put("msgtype", "textcard");
        weixineeParams.put("title", "预警消息通知");
        weixineeParams.put("description", "您共有"+sum+"个预警超期未处理！");
        weixineeParams.put("url", ("/csqlh.zzyjjt.com"+PC_URL));//移动端点击的url
        weixineeParams.put("btntxt", "点击查看");
        parameter.setWeixineeParams(weixineeParams);

        CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
        if (result.isSuccess()) {
            logger.error("消息发送成功---------------->,接收人:{}," + result.getMsg(), Arrays.toString(receivers));

            return true;
        } else {
            logger.error("消息发送失败---------------->" + result.getMsg());
            return false;
        }
    }
    @PostMapping(value = "execute")
    public CommonResponse<List<JSONObject>> execute(HttpServletRequest request) {
        logger.info("消息发送前1---------------->");
        List<TaskVO> enrollEntities = warnService.selectWarnList();
        logger.info("消息发送前2---------------->");
        //提取消息接收人id
        List<String> receiverIdList = enrollEntities.stream().map(TaskVO::getReceiverId).map(s -> String.valueOf(s)).collect(Collectors.toList());
        //提取未处理预警总数
        List<Integer> sumList = enrollEntities.stream().map(TaskVO::getSum).collect(Collectors.toList());
        logger.info("消息发送前3---------------->");
//        String[] receiverIds = new String[receiverIdList.size()];
//        String[] sums = new String[sumList.size()];
        //发送消息
        for (int i = 0; i < receiverIdList.size(); i++) {
            sendSys(receiverIdList.get(i) ,sumList.get(i));
            sendWeixin(receiverIdList.get(i) ,sumList.get(i));
            try {
                //睡眠0.5s
                Thread.currentThread().sleep(500);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }

        }

        //boolean send = send( collect.toArray(s),collect1.toArray(strings));
        return CommonResponse.success("执行成功！");
//
//
//        logger.info("接收到 Task 参数：{}", jsonParam);
//        List<EarlyWarnTransVO> warnList = new ArrayList<>();
//        String warnCode = null;
//
//
//        for (int i = 0; i < jsonParam.size(); i++) {
//            JSONObject o = jsonParam.getJSONObject(i);
//            Long tenantId = o.getLong("tenantId");
//            warnCode = o.getString("warnCode");
//            JSONArray orgSettings = o.getJSONArray("settings");
//
//            // 1、根据租户合同纬度，查询合同
//            // 2、根据合同的单据所属组织，找到对应的预警设置，也就是这条合同适用于那个设置
//            // 3、根据预警设置判断该合同数据属于哪个等级
//            // 4、符合等级，则拼接预警数据，并保存到 list
//            // 5、发送数据
//
//            List<TaskVO> enrollEntities = warnService.selectWarnList();
//
//            if (ListUtil.isNotEmpty(enrollEntities)) {
//                for (EnrollEntity costAdjustEntity : enrollEntities) {
//                    JSONObject orgSet = null;
//                    JSONObject defaultSet = null;
//                    Long orgId = costAdjustEntity.getOrgId();
//                    OrgVO orgVO = iOrgApi.getOneById(orgId).getData();
//                    if (orgVO == null) {
//                        continue;
//                    }
//                    String innerCode = orgVO.getInnerCode();
//                    String[] parentIds = innerCode.split("\\|");
//                    /**
//                     * 如果当前组织没查到配置，则找其直接上级的配置，
//                     * 再找不到，再找其上级，以此类推，
//                     * 直至上级为空，还没找到则用默认配置，
//                     * 默认配置为空，则不预警
//                     * 使用当前组织的 innerCode 进行父级查找
//                     * */
//                    logger.info("parentIds______" + innerCode);
//                    for (int i1 = parentIds.length - 1; i1 >= 0; i1--) {
//                        /** 反向查找 */
//                        Long pOrgId = Long.parseLong(parentIds[i1]);
//                        for (int j = 0; j < orgSettings.size(); j++) {
//                            JSONObject set = orgSettings.getJSONObject(j);
//                            if (pOrgId.equals(set.getLong("orgId"))) {
//                                orgSet = set;
//                                break;
//                            }
//                        }
//                        if (orgSet != null) {
//                            break;
//                        }
//                    }
//                    /** 查找默认的 */
//                    for (int i1 = 0; i1 < orgSettings.size(); i1++) {
//                        JSONObject set = orgSettings.getJSONObject(i1);
//                        if (set.getBoolean("default")) {
//                            defaultSet = set;
//                            break;
//                        }
//                    }
//                    if (orgSet == null) {
//                        /** 使用默认配置 */
//                        orgSet = defaultSet;
//                    }
//                    if (orgSet != null && ListUtil.isNotEmpty(orgSet.getJSONArray("warningSetings"))) {
//
//                        JSONArray warningSettings = orgSet.getJSONArray("warningSetings");
//                        boolean high = false;
//                        boolean meddle = false;
//                        boolean low = false;
//                        JSONObject useSetHigh = null;
//                        JSONObject useSetMeddle = null;
//                        JSONObject useSetLow = null;
//
//                        Date now = new Date();
//                        for (int i1 = 0; i1 < warningSettings.size(); i1++) {
//                            JSONObject set = warningSettings.getJSONObject(i1);
//                            day = set.getBigDecimal("parameterValue").intValue();
//                            if ("高".equals(set.getString("warningLevel"))) {
//                                if ((costAdjustEntity.getBiddingDate().getTime() - now.getTime()) / (1000 * 60 * 60 * 24) <= day) {
//                                    high = true;
//                                    useSetHigh = set;
//                                }
//                            }
//                            if ("中".equals(set.getString("warningLevel"))) {
//                                if ((costAdjustEntity.getBiddingDate().getTime() - now.getTime()) / (1000 * 60 * 60 * 24) <= day) {
//                                    meddle = true;
//                                    useSetMeddle = set;
//                                }
//                            }
//                            if ("低".equals(set.getString("warningLevel"))) {
//                                if ((costAdjustEntity.getBiddingDate().getTime() - now.getTime()) / (1000 * 60 * 60 * 24) <= day) {
//                                    low = true;
//                                    useSetLow = set;
//                                }
//                            }
//                        }
//
//                        if (high || meddle || low) {
//                            EarlyWarnTransVO vo = new EarlyWarnTransVO();
//                            vo.setBillName(orgSet.getString("moduleName") + "-" +
//                                    costAdjustEntity.getBillCode());
//                            vo.setPcTitle("投标报名");
//                            vo.setPcUrl(PC_URL + costAdjustEntity.getId());
//                            vo.setOrgId(costAdjustEntity.getOrgId());
//                            //发送消息，根据角色和组织找人，指定找人组织，多个以半角逗号分割
//                            vo.setSendOrgId(costAdjustEntity.getOrgId() + "");
//                            vo.setOrgName(costAdjustEntity.getOrgName());
//                            vo.setSourceId(costAdjustEntity.getId().toString());
//                            vo.setTenantId(tenantId);
//                            vo.setWarnSetId(orgSet.getLong("warnId"));
//                            vo.setEarlywarnName(orgSet.getString("warnName"));
//                            vo.setWarnType(orgSet.getString("warnType"));
//                            String tmpContent = orgSet.getString("warningContentTemplate");
//                            if (high) {
//                                vo.setWarnLevel("高");
//                                vo.setWarnSetParamId(useSetHigh.getLong("id"));
//                                vo.setEarlywarnContent(
//                                        tmpContent.replaceAll("#projectName#", costAdjustEntity.getEngineeringName())
//                                                .replaceAll("#day#", day.toString())
//                                );
//                            } else if (meddle) {
//                                vo.setWarnLevel("中");
//                                vo.setWarnSetParamId(useSetMeddle.getLong("id"));
//                                vo.setEarlywarnContent(
//                                        tmpContent.replaceAll("#projectName#", costAdjustEntity.getEngineeringName())
//                                                .replaceAll("#day#", day.toString())
//                                );
//                            } else {
//                                vo.setWarnLevel("低");
//                                vo.setWarnSetParamId(useSetLow.getLong("id"));
//                                vo.setEarlywarnContent(
//                                        tmpContent.replaceAll("#projectName#", costAdjustEntity.getEngineeringName())
//                                                .replaceAll("#day#", day.toString())
//                                );
//                            }
//                            warnList.add(vo);
//                        }
//                    }
//                }
//            }
//        }
//        return sendWarnToTask(warnList,warnCode);
    }

    private CommonResponse<String> sendWarnToTask(List<EarlyWarnTransVO> warnList, String warnCode) {
        CommonResponse<String> warnResp = warnCenterApi.sendToWarnCenterByCode(warnList, warnCode);
        if (!warnResp.isSuccess()) {
            logger.error("回调预警任务服务失败，{}", warnResp.getMsg());
            return CommonResponse.error("回调预警任务服务失败" + warnResp.getMsg());
        }
        return CommonResponse.success("任务接受处理成功！");
    }











//        logger.info("接收到Task参数：{}", jsonParam);
//        List<EarlyWarnTransVO> warnList = new ArrayList<>();
//        String warnCode = null;
//        if (jsonParam.size() > 0) {
//            JSONObject o = jsonParam.getJSONObject(0);
//            Long tenantId = o.getLong("tenantId");
//            warnCode = o.getString("warnCode");
//            JSONArray settings = o.getJSONArray("settings");
//            JSONObject orgSet = null;
//            JSONObject defaultSet = null;
//
//            /** 查找默认的 */
//            for (int i1 = 0; i1 < settings.size(); i1++) {
//                JSONObject set = settings.getJSONObject(i1);
//                if (set.getBoolean("default")) {
//                    defaultSet = set;
//                    break;
//                }
//            }
//            if (orgSet == null) {
//                /** 使用默认配置 */
//                orgSet = defaultSet;
//            }
//            if (orgSet != null && ListUtil.isNotEmpty(orgSet.getJSONArray("warningSetings"))) {
//
//                JSONArray warningSetings = orgSet.getJSONArray("warningSetings");
//                JSONObject billParams = warningSetings.getJSONObject(0);
//                String parameterValue = billParams.getString("parameterValue");
//
//                Integer day = 7;
//                if (StringUtils.isNotEmpty(parameterValue)) {
//                    day = Integer.valueOf(parameterValue);
//                }
//
//                List<EnrollEntity> enrollEntityList = new ArrayList<>();
//                Date now = new Date();
//                List<EnrollEntity> enrollEntities = enrollService.selectEnrollListIsBidding();
//                for (EnrollEntity entity : enrollEntities) {
//                    //如果当前时间-开标日期 > 7天  则将该项目放入列表  9.25   开标日期-当前时间 <= 7
//                    if ((now.getTime() - entity.getBiddingDate().getTime()) / (1000 * 60 * 60 * 24) >= day) {
//                        enrollEntityList.add(entity);
//                    }
//                }
//
//
//                if (CollectionUtils.isEmpty(enrollEntityList)) {
//                    logger.error("执行完成，未发现有匹配规则的项目信息！");
//                    return sendWarnToTask(new ArrayList<>(), warnCode);
//                }
//
//                return sendWarnToTask(transToWarnVO(enrollEntityList, orgSet,billParams, day), warnCode);
//            }else {
//                return CommonResponse.error("获取参数失败！");
//            }
//    }
//    return CommonResponse.error("获取参数失败！");
//    }
//
//
//    /**
//     * 调用预警中心API发送预警消息
//     *
//     * @param warnList 预警消息列表
//     * @param warnCode 预警设置Id
//     * @return
//     */
//    private CommonResponse<String> sendWarnToTask(List<EarlyWarnTransVO> warnList, String warnCode) {
//        CommonResponse<String> warnResp = warnCenterApi.sendToWarnCenterByCode(warnList, warnCode);
//        if(!warnResp.isSuccess()) {
//            logger.error("回调预警任务服务失败，{}", warnResp.getMsg());
//            return CommonResponse.error("回调预警任务服务失败" + warnResp.getMsg());
//        }
//
//        return CommonResponse.success("任务接受处理成功！");
//    }
//
//    /**
//     * 将查询出来的业务数据列表按照预警模板转换为预警消息列表
//     *
//     * @param result 业务数据列表
//     * @param orgSet 默认预警设置信息
//     * @return
//     */
//    private List<EarlyWarnTransVO> transToWarnVO(List<EnrollEntity> result, JSONObject orgSet,JSONObject billParams,Integer day) {
//        List<EarlyWarnTransVO> resp = new ArrayList<>();
//        String tmpContent = null;
//        for(EnrollEntity m : result) {
//            EarlyWarnTransVO vo = new EarlyWarnTransVO();
//            //预警显示 单据名称
//            vo.setBillName((null != orgSet.get("moduleName") ? orgSet.get("moduleName").toString() + " - " : "")  + m.getEngineeringName());
//            //单据详情页页签 名称
//            vo.setPcTitle("投标报名");
//            //
//            vo.setPcUrl(PC_URL +m.getId());
//            //组织Id
//            vo.setOrgId(m.getOrgId());
//            //发送消息，根据角色和组织找人，指定找人组织，多个以半角逗号分割
//            vo.setSendOrgId(m.getOrgId()+"");
//            //组织名称
//            vo.setOrgName(m.getOrgName());
//            //单据Id
//            vo.setSourceId(m.getBillCode());
//            //单据所属租户Id
//            vo.setTenantId(999999L);
//            //预警等级
//            vo.setWarnLevel(billParams.getString("warningLevel"));
//
//            vo.setWarnSetParamId(billParams.getLong("id"));
//            //预警设置Id
//            vo.setWarnSetId(orgSet.getLong("warnId"));
//            //预警设置名称
//            vo.setEarlywarnName(orgSet.getString("warnName"));
//
//            vo.setWarnType(orgSet.getString("warnType"));
//
//            //预警内容模板
//            tmpContent = orgSet.getString("warningContentTemplate");
//            //预警内容
//            vo.setEarlywarnContent(
//                    tmpContent.replaceAll("#projectName#", m.getEngineeringName())
//                                .replaceAll("#day#", day.toString())
//            );
//
//            resp.add(vo);
//        }
//
//        logger.info("发送预警参数：{}", JSON.toJSONString(resp));
//        return resp;
//    }

}

==> ejc-bpmdesktop-impl-3.0.0-20230321.064358-32-sources.jar: com/ejianc/business/desktop/controller/WarnController.java <==
package com.ejianc.business.desktop.controller;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.center.api.IWarnCenterApi;
import com.ejianc.business.center.vo.EarlyWarnTransVO;
import com.ejianc.business.desktop.service.IWarnService;
import com.ejianc.business.desktop.vo.TaskVO;
import com.ejianc.foundation.message.api.IPushMessageApi;
import com.ejianc.foundation.message.vo.PushMsgParameter;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @author:sunxy
 * @Description:超期待办预警
 * @date 2022/6/6 11:22
 */
@RestController
@RequestMapping(value = "/warn/")
public class WarnController {
//       * * * 26 * ?            {"dispatchCode":"WARNING000110"}
   //    dispatchWarningHandler
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IWarnService warnService;
    @Autowired
    private IWarnCenterApi warnCenterApi;

    @Autowired
    private IOrgApi iOrgApi;

    static  String  PC_URL = "/ejc-task-frontend/#/personWarnCenter";
    static  String  PC_URL1 = "/ejc-message-frontend/#/message?msgType=bpmurge";
    static  String  TEST_AGENTID = "1000038";
    static  String  TEST_SECRET = "0n0MCtZ1vNtJsKQWPIREQ1UNMM8BXDkQZat6nbRqGGE";
    static  String  PRO_AGENTID = "1000036";
    static  String  PRO_SECRET = "dBMuo3hXenzW-6B3U8BfscMDQWSr3ET1nfwUaqDPi40";


    @Autowired
    private IPushMessageApi pushMessageApi;
    //预警代办提醒
    public boolean sendSys(String receiverId,Integer sum){

        PushMsgParameter parameter = new PushMsgParameter();
        List<String> channel = new ArrayList<>();
        channel.add(PushMsgParameter.CHANNEL_TYPE_WEXINEE);//发送企业微信标志
        channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
        String[] receivers = {receiverId};
        parameter.setReceivers(receivers);// 收信人
        parameter.setChannel(channel.toArray(new String[channel.size()]));// 消息类型
        parameter.setMsgType("earlywarning");//预警消息
        parameter.setSubject("您共有"+sum+"个预警超期未处理！");// 标题
        parameter.setContent("内容");// 内容
        parameter.setPcUrl(PC_URL);// pc端url
        parameter.setMobileUrl(PC_URL);// 移动端url
        parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
        parameter.setSendUserId(InvocationInfoProxy.getUserid());
        JSONObject weixineeParams = new JSONObject();
        weixineeParams.put("agentid", "1000036");//企业微信应用id
        weixineeParams.put("secret", "dBMuo3hXenzW-6B3U8BfscMDQWSr3ET1nfwUaqDPi40");//企业微信secret
        weixineeParams.put("msgtype", "textcard");
        weixineeParams.put("title", "预警超期未处理通知");
        weixineeParams.put("description", "您共有"+sum+"个预警超期未处理！请前往电脑端查看！");
        weixineeParams.put("url", ("https://pms.zzyjjt.com/portal/sso/index?&userid="+receiverId+
                "&targeturl=https%3A%2F%2Fpms.zzyjjt.com%2Fejc-task-frontend%2F%23%2FpersonWarnCenter"));//移动端点击的url
        weixineeParams.put("btntxt", "点击查看");
        parameter.setWeixineeParams(weixineeParams);

        CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
        if (result.isSuccess()) {
            logger.error("消息发送成功---------------->,接收人:{}," + result.getMsg(), Arrays.toString(receivers));

            return true;
        } else {
            logger.error("消息发送失败---------------->" + result.getMsg());
            return false;
        }
    }


    @PostMapping(value = "execute")
    public CommonResponse<List<JSONObject>> execute(HttpServletRequest request) {
        logger.info("消息发送前1---------------->");
        List<TaskVO> enrollEntities = warnService.selectWarnList();
        logger.info("消息发送前2---------------->");
        //发送消息
        for (TaskVO taskEntity : enrollEntities) {
            sendSys(taskEntity.getReceiverId()+"",taskEntity.getSum());
            try {
                //睡眠0.5s
                Thread.currentThread().sleep(500);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
        return CommonResponse.success("执行成功！");
    }


    //流程代办提醒
    public boolean sendSys1(String receiverId,Integer sum){

        PushMsgParameter parameter = new PushMsgParameter();
        List<String> channel = new ArrayList<>();
        channel.add(PushMsgParameter.CHANNEL_TYPE_WEXINEE);//发送企业微信标志
        channel.add(PushMsgParameter.CHANNEL_TYPE_SYS);
        String[] receivers = {receiverId};
        parameter.setReceivers(receivers);// 收信人
        parameter.setChannel(channel.toArray(new String[channel.size()]));// 消息类型
        parameter.setMsgType("earlywarning");//预警消息
        parameter.setSubject("您共有"+sum+"条待办（含预警任务）超48小时未处理，请到（待办中心或消息-流程催办提醒）及时处理！");// 标题
        parameter.setContent("内容");// 内容
        parameter.setPcUrl(PC_URL1);// pc端url
        parameter.setMobileUrl(PC_URL1);// 移动端url
        parameter.setTenantId(InvocationInfoProxy.getTenantid().toString());
        parameter.setSendUserId(InvocationInfoProxy.getUserid());
        JSONObject weixineeParams = new JSONObject();
        weixineeParams.put("agentid",PRO_AGENTID);//企业微信应用id
        weixineeParams.put("secret", PRO_SECRET);//企业微信secret
        weixineeParams.put("msgtype", "textcard");
        weixineeParams.put("title", "流程审批超期未处理通知");
        weixineeParams.put("description", "您共有"+sum+"条待办（含预警任务）超48小时未处理，请到（待办中心或消息-流程催办提醒）及时处理！请前往电脑端查看！");
        weixineeParams.put("url", ("https://pms.zzyjjt.com/portal/sso/index?&userid="+receiverId+
                "&targeturl=https%3A%2F%2Fpms.zzyjjt.com%2Fejc-message-frontend%2F%23%2Fmessage%3FmsgType%3Dbpmurge"));//移动端点击的url
        weixineeParams.put("btntxt", "点击查看");
        parameter.setWeixineeParams(weixineeParams);

        CommonResponse<String> result = pushMessageApi.pushMessage(parameter);
        if (result.isSuccess()) {
            logger.info("消息发送成功---------------->,接收人:{},数量：{}", Arrays.toString(receivers),sum);

            return true;
        } else {
            logger.error("消息发送失败---------------->" + result.getMsg());
            return false;
        }
    }

    @PostMapping(value = "executeMsg")
    public CommonResponse<List<JSONObject>> executeMsg(HttpServletRequest request) {
        logger.info("消息发送前1---------------->");
        List<TaskVO> enrollEntities = warnService.selectMsgWarnList();
        logger.info("消息发送前2---------------->");
        //发送消息
        for (TaskVO taskEntity : enrollEntities) {
            sendSys1(taskEntity.getReceiverId()+"",taskEntity.getSum());
            try {
                //睡眠0.5s
                Thread.currentThread().sleep(500);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
        return CommonResponse.success("执行成功！");
    }
}
